summaryrefslogtreecommitdiffhomepage
path: root/examples/advanced.c
diff options
context:
space:
mode:
authorTyge Løvset <[email protected]>2020-09-15 23:12:58 +0200
committerTyge Løvset <[email protected]>2020-09-15 23:12:58 +0200
commit0ce57669673a5a22d8207ec884bcebb97cb18448 (patch)
treed76c4b38431efee766d97ba572fa3127a3e05976 /examples/advanced.c
parentf4435af2fc9e9187f7be0149c2eb916db27cb257 (diff)
downloadSTC-modified-0ce57669673a5a22d8207ec884bcebb97cb18448.tar.gz
STC-modified-0ce57669673a5a22d8207ec884bcebb97cb18448.zip
Simplified declare_ statement e.g. c_cmap(...)
Diffstat (limited to 'examples/advanced.c')
-rw-r--r--examples/advanced.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/advanced.c b/examples/advanced.c
index ab2cec5f..1f4907c6 100644
--- a/examples/advanced.c
+++ b/examples/advanced.c
@@ -50,8 +50,8 @@ Viking viking_fromVw(VikingVw vw) {
Viking vk = {cstr(vw.name), cstr(vw.country)}; return vk;
}
-// Using the full cdef_cmap() macro to define [Viking -> int] hash map type:
-cdef_cmap(vk, Viking, int, c_default_destroy, vikingvw_equals, vikingvw_hash,
+// Using the full c_cmap() macro to define [Viking -> int] hash map type:
+c_cmap(vk, Viking, int, c_default_destroy, vikingvw_equals, vikingvw_hash,
viking_destroy, VikingVw, viking_toVw, viking_fromVw);
// cmap_vk uses vikingvw_hash() for hash value calculations, and vikingvw_equals() for equality test.